==> aom-docs-3.0.0-2-aarch64.pkg.tar.xz: usr/share/doc/aom/encoder_8h.js <==
var encoder_8h =
[
    [ "ResizeCfg", "structResizeCfg.html", "structResizeCfg" ],
    [ "PartitionCfg", "structPartitionCfg.html", "structPartitionCfg" ],
    [ "IntraModeCfg", "structIntraModeCfg.html", "structIntraModeCfg" ],
    [ "TxfmSizeTypeCfg", "structTxfmSizeTypeCfg.html", "structTxfmSizeTypeCfg" ],
    [ "CompoundTypeCfg", "structCompoundTypeCfg.html", "structCompoundTypeCfg" ],
    [ "SuperResCfg", "structSuperResCfg.html", "structSuperResCfg" ],
    [ "KeyFrameCfg", "structKeyFrameCfg.html", "structKeyFrameCfg" ],
    [ "RateControlCfg", "structRateControlCfg.html", "structRateControlCfg" ],
    [ "AlgoCfg", "structAlgoCfg.html", "structAlgoCfg" ],
    [ "AV1EncoderConfig", "structAV1EncoderConfig.html", "structAV1EncoderConfig" ],
    [ "FrameProbInfo", "structFrameProbInfo.html", "structFrameProbInfo" ],
    [ "inter_modes_info", "structinter__modes__info.html", "structinter__modes__info" ],
    [ "VarBasedPartitionInfo", "structVarBasedPartitionInfo.html", "structVarBasedPartitionInfo" ],
    [ "AV1EncRowMultiThreadSync", "structAV1EncRowMultiThreadSync.html", "structAV1EncRowMultiThreadSync" ],
    [ "AV1EncRowMultiThreadInfo", "structAV1EncRowMultiThreadInfo.html", "structAV1EncRowMultiThreadInfo" ],
    [ "MultiThreadInfo", "structMultiThreadInfo.html", "structMultiThreadInfo" ],
    [ "ForceIntegerMVInfo", "structForceIntegerMVInfo.html", "structForceIntegerMVInfo" ],
    [ "MBMIExtFrameBufferInfo", "structMBMIExtFrameBufferInfo.html", "structMBMIExtFrameBufferInfo" ],
    [ "GlobalMotionInfo", "structGlobalMotionInfo.html", "structGlobalMotionInfo" ],
    [ "InitialDimensions", "structInitialDimensions.html", "structInitialDimensions" ],
    [ "InterpSearchFlags", "structInterpSearchFlags.html", "structInterpSearchFlags" ],
    [ "MotionVectorSearchParams", "structMotionVectorSearchParams.html", "structMotionVectorSearchParams" ],
    [ "RefreshFrameFlagsInfo", "structRefreshFrameFlagsInfo.html", "structRefreshFrameFlagsInfo" ],
    [ "ResizePendingParams", "structResizePendingParams.html", "structResizePendingParams" ],
    [ "RefFrameDistanceInfo", "structRefFrameDistanceInfo.html", "structRefFrameDistanceInfo" ],
    [ "WinnerModeParams", "structWinnerModeParams.html", "structWinnerModeParams" ],
    [ "ExtRefreshFrameFlagsInfo", "structExtRefreshFrameFlagsInfo.html", "structExtRefreshFrameFlagsInfo" ],
    [ "ExternalFlags", "structExternalFlags.html", "structExternalFlags" ],
    [ "EncSegmentationInfo", "structEncSegmentationInfo.html", "structEncSegmentationInfo" ],
    [ "TimeStamps", "structTimeStamps.html", "structTimeStamps" ],
    [ "CoeffBufferPool", "structCoeffBufferPool.html", "structCoeffBufferPool" ],
    [ "AV1_COMP", "structAV1__COMP.html", "structAV1__COMP" ],
    [ "EncodeFrameInput", "structEncodeFrameInput.html", null ],
    [ "EncodeFrameParams", "structEncodeFrameParams.html", "structEncodeFrameParams" ],
    [ "AV1EncoderConfig", "encoder_8h.html#ae37f210917b9733abc7ca81445427d71", null ],
    [ "InterModesInfo", "encoder_8h.html#a9f8c3abfb05222c315bd3051a142c718", null ],
    [ "MultiThreadInfo", "encoder_8h.html#a371e7dff2f6e26ebcb3ac61fd872a21f", null ],
    [ "AV1_COMP", "encoder_8h.html#a0207efa57c443f3ff9e157c22c532b5f", null ],
    [ "EncodeFrameInput", "encoder_8h.html#a246db68993252fe81c1e5a911575efb4", null ],
    [ "EncodeFrameParams", "encoder_8h.html#a1abd57b3c653bb72dee5f88ba45f1cda", null ],
    [ "av1_receive_raw_frame", "group__high__level__algo.html#ga681c10fbb05a4c91b4536107f3342c37", null ],
    [ "av1_get_compressed_data", "group__high__level__algo.html#gae1ceea4df4210e2464865ea90d5aa9ca", null ],
    [ "av1_encode", "group__high__level__algo.html#gad4f93a0174051f16f9010f332f6c9bc7", null ],
    [ "has_no_stats_stage", "group__two__pass__algo.html#ga737bbff8d05e931b73b4321a0fa35d0e", null ]
];

==> aom-docs-3.1.1-1-aarch64.pkg.tar.xz: usr/share/doc/aom/encoder_8h.js <==
var encoder_8h =
[
    [ "ResizeCfg", "structResizeCfg.html", "structResizeCfg" ],
    [ "PartitionCfg", "structPartitionCfg.html", "structPartitionCfg" ],
    [ "IntraModeCfg", "structIntraModeCfg.html", "structIntraModeCfg" ],
    [ "TxfmSizeTypeCfg", "structTxfmSizeTypeCfg.html", "structTxfmSizeTypeCfg" ],
    [ "CompoundTypeCfg", "structCompoundTypeCfg.html", "structCompoundTypeCfg" ],
    [ "SuperResCfg", "structSuperResCfg.html", "structSuperResCfg" ],
    [ "KeyFrameCfg", "structKeyFrameCfg.html", "structKeyFrameCfg" ],
    [ "RateControlCfg", "structRateControlCfg.html", "structRateControlCfg" ],
    [ "AlgoCfg", "structAlgoCfg.html", "structAlgoCfg" ],
    [ "AV1EncoderConfig", "structAV1EncoderConfig.html", "structAV1EncoderConfig" ],
    [ "FrameProbInfo", "structFrameProbInfo.html", "structFrameProbInfo" ],
    [ "inter_modes_info", "structinter__modes__info.html", "structinter__modes__info" ],
    [ "VarBasedPartitionInfo", "structVarBasedPartitionInfo.html", "structVarBasedPartitionInfo" ],
    [ "AV1EncRowMultiThreadSync", "structAV1EncRowMultiThreadSync.html", "structAV1EncRowMultiThreadSync" ],
    [ "AV1EncRowMultiThreadInfo", "structAV1EncRowMultiThreadInfo.html", "structAV1EncRowMultiThreadInfo" ],
    [ "MultiThreadInfo", "structMultiThreadInfo.html", "structMultiThreadInfo" ],
    [ "ForceIntegerMVInfo", "structForceIntegerMVInfo.html", "structForceIntegerMVInfo" ],
    [ "MBMIExtFrameBufferInfo", "structMBMIExtFrameBufferInfo.html", "structMBMIExtFrameBufferInfo" ],
    [ "GlobalMotionInfo", "structGlobalMotionInfo.html", "structGlobalMotionInfo" ],
    [ "InitialDimensions", "structInitialDimensions.html", "structInitialDimensions" ],
    [ "InterpSearchFlags", "structInterpSearchFlags.html", "structInterpSearchFlags" ],
    [ "MotionVectorSearchParams", "structMotionVectorSearchParams.html", "structMotionVectorSearchParams" ],
    [ "RefreshFrameFlagsInfo", "structRefreshFrameFlagsInfo.html", "structRefreshFrameFlagsInfo" ],
    [ "ResizePendingParams", "structResizePendingParams.html", "structResizePendingParams" ],
    [ "RefFrameDistanceInfo", "structRefFrameDistanceInfo.html", "structRefFrameDistanceInfo" ],
    [ "WinnerModeParams", "structWinnerModeParams.html", "structWinnerModeParams" ],
    [ "ExtRefreshFrameFlagsInfo", "structExtRefreshFrameFlagsInfo.html", "structExtRefreshFrameFlagsInfo" ],
    [ "ExternalFlags", "structExternalFlags.html", "structExternalFlags" ],
    [ "EncSegmentationInfo", "structEncSegmentationInfo.html", "structEncSegmentationInfo" ],
    [ "TimeStamps", "structTimeStamps.html", "structTimeStamps" ],
    [ "CoeffBufferPool", "structCoeffBufferPool.html", "structCoeffBufferPool" ],
    [ "AV1_PRIMARY", "structAV1__PRIMARY.html", "structAV1__PRIMARY" ],
    [ "AV1_COMP", "structAV1__COMP.html", "structAV1__COMP" ],
    [ "EncodeFrameInput", "structEncodeFrameInput.html", null ],
    [ "EncodeFrameParams", "structEncodeFrameParams.html", "structEncodeFrameParams" ],
    [ "AV1EncoderConfig", "encoder_8h.html#ae37f210917b9733abc7ca81445427d71", null ],
    [ "InterModesInfo", "encoder_8h.html#a9f8c3abfb05222c315bd3051a142c718", null ],
    [ "MultiThreadInfo", "encoder_8h.html#a371e7dff2f6e26ebcb3ac61fd872a21f", null ],
    [ "AV1_PRIMARY", "encoder_8h.html#a9af93120431b9d96ca04670151ea562c", null ],
    [ "AV1_COMP", "encoder_8h.html#a0207efa57c443f3ff9e157c22c532b5f", null ],
    [ "EncodeFrameInput", "encoder_8h.html#a246db68993252fe81c1e5a911575efb4", null ],
    [ "EncodeFrameParams", "encoder_8h.html#a1abd57b3c653bb72dee5f88ba45f1cda", null ],
    [ "COST_UPDATE_TYPE", "encoder_8h.html#a03bce75164cb579c775759205ed26055", [
      [ "COST_UPD_SB", "encoder_8h.html#a03bce75164cb579c775759205ed26055a7ab17ad52ce554037df368d89cef2c02", null ],
      [ "COST_UPD_SBROW", "encoder_8h.html#a03bce75164cb579c775759205ed26055a0387b2a2bbc01b142f3716c18a97fe9d", null ],
      [ "COST_UPD_TILE", "encoder_8h.html#a03bce75164cb579c775759205ed26055a6e437058362eef3c17fc5c856202dee3", null ],
      [ "COST_UPD_OFF", "encoder_8h.html#a03bce75164cb579c775759205ed26055a6f0f4239b7fc9f98980631093f885cc0", null ]
    ] ],
    [ "av1_receive_raw_frame", "group__high__level__algo.html#ga681c10fbb05a4c91b4536107f3342c37", null ],
    [ "av1_get_compressed_data", "group__high__level__algo.html#gae1ceea4df4210e2464865ea90d5aa9ca", null ],
    [ "av1_encode", "group__high__level__algo.html#gad4f93a0174051f16f9010f332f6c9bc7", null ],
    [ "has_no_stats_stage", "group__two__pass__algo.html#ga737bbff8d05e931b73b4321a0fa35d0e", null ]
];
